Documentation
¶
Index ¶
Constants ¶
const ( // ShutdownTimeout is the time given for outstanding requests to finish before shutdown. DefaultShutdownTimeout = 10 * time.Second )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Config ¶
type Config struct {
Scheme string `toml:"scheme"`
Host string `toml:"host"`
Port string `toml:"port"`
Prometheus PrometheusConfig `toml:"prometheus"`
}
type PrometheusConfig ¶ added in v0.4.0
type Server ¶
type Server struct {
LinkService shortly.LinkService
Prom struct {
// contains filtered or unexported fields
}
// contains filtered or unexported fields
}
func (*Server) MetricsPort ¶ added in v0.4.0
MetricsPort returns the TCP port for the running metrics server. This is useful in tests where we allocate a random port by using ":0".
Click to show internal directories.
Click to hide internal directories.